% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/runCCA.R
\name{runCCA}
\alias{runCCA}
\alias{calculateCCA}
\alias{calculateRDA}
\alias{runRDA}
\alias{calculateCCA,ANY-method}
\alias{calculateCCA,SummarizedExperiment-method}
\alias{runCCA,SingleCellExperiment-method}
\alias{calculateRDA,ANY-method}
\alias{calculateRDA,SummarizedExperiment-method}
\alias{runRDA,SingleCellExperiment-method}
\title{Canonical Correspondence Analysis}
\usage{
calculateCCA(x, ...)

runCCA(x, ...)

calculateRDA(x, ...)

runRDA(x, ...)

\S4method{calculateCCA}{ANY}(x, formula, variables, scale = TRUE, ...)

\S4method{calculateCCA}{SummarizedExperiment}(
  x,
  formula,
  variables,
  ...,
  assay.type = assay_name,
  assay_name = exprs_values,
  exprs_values = "counts"
)

\S4method{runCCA}{SingleCellExperiment}(x, ..., altexp = NULL, name = "CCA")

\S4method{calculateRDA}{ANY}(x, formula, variables, ...)

\S4method{calculateRDA}{SummarizedExperiment}(
  x,
  formula,
  variables,
  ...,
  assay.type = assay_name,
  assay_name = exprs_values,
  exprs_values = "counts"
)

\S4method{runRDA}{SingleCellExperiment}(x, ..., altexp = NULL, name = "RDA")
}
\arguments{
\item{x}{For \code{calculate*} a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
or a numeric matrix with columns as samples

For \code{run*} a
\code{\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment}}
or a derived object.}

\item{...}{additional arguments passed to vegan::cca or vegan::dbrda}

\item{formula}{If \code{x} is a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
a formula can be supplied. Based on the right-hand side of the given formula
\code{colData} is subset to \code{variables}.

\code{variables} and \code{formula} can be missing, which turns the CCA analysis
into a CA analysis and dbRDA into PCoA/MDS.}

\item{variables}{When \code{x} is a \code{SummarizedExperiment},
\code{variables} can be used to specify variables from \code{colData}.

When \code{x} is a matrix, \code{variables} is a \code{data.frame} or
an object coercible to one containing the variables to use.

All variables are used. Please subset, if you want to consider only some of them.
\code{variables} and \code{formula} can be missing, which turns the CCA analysis
into a CA analysis and dbRDA into PCoA/MDS.}

\item{scale}{a logical scalar, should the expression values be standardized?
\code{scale} is disabled when using \code{*RDA} functions. Please scale before
performing RDA (Check examples.)}

\item{assay.type}{a single \code{character} value for specifying which
assay to use for calculation.}

\item{assay_name}{a single \code{character} value for specifying which
assay to use for calculation.
(Please use \code{assay.type} instead. At some point \code{assay_name}
will be disabled.)}

\item{exprs_values}{a single \code{character} value for specifying which
assay to use for calculation.
(Please use \code{assay.type} instead.)}

\item{altexp}{String or integer scalar specifying an alternative experiment
containing the input data.}

\item{name}{String specifying the name to be used to store the result in the
reducedDims of the output.}
}
\value{
For \code{calculateCCA} a matrix with samples as rows and CCA dimensions as
columns

For \code{runCCA} a modified \code{x} with the results stored in
\code{reducedDim} as the given \code{name}
}
\description{
These functions perform Canonical Correspondence Analysis on data stored
in a \code{SummarizedExperiment}.
}
\details{
*CCA functions utilize \code{vegan:cca} and *RDA functions \code{vegan:dbRDA}.
By default dbRDA is done with euclidean distances which equals to RDA.
}
\examples{
library(scater)
data(GlobalPatterns)
GlobalPatterns <- runCCA(GlobalPatterns, data ~ SampleType)
plotReducedDim(GlobalPatterns,"CCA", colour_by = "SampleType")

GlobalPatterns <- runRDA(GlobalPatterns, data ~ SampleType)
plotReducedDim(GlobalPatterns,"CCA", colour_by = "SampleType")

# To scale values when using *RDA functions, use transformCounts(MARGIN = "features", 
tse <- GlobalPatterns
tse <- transformCounts(tse, MARGIN = "features", method = "z")
# Data might include taxa that do not vary. Remove those because after z-transform
# their value is NA
tse <- tse[ rowSums( is.na( assay(tse, "z") ) ) == 0, ]
# Calculate RDA
tse <- runRDA(tse, formula = data ~ SampleType, 
              assay.type = "z", name = "rda_scaled", na.action = na.omit)
# Plot
plotReducedDim(tse,"rda_scaled", colour_by = "SampleType")
}
\seealso{
For more details on the actual implementation see \code{\link[vegan:cca]{cca}}
and \code{\link[vegan:dbrda]{dbrda}}
}
